@@ -45,6 +45,7 @@ __all__ = ["DataServer"]
 API_ERRORS = DatafeedError, SecurityError, FieldError, NotImplementedError
 CONN_ERRORS = tornado.gen.TimeoutError, tornado.iostream.StreamClosedError
 REREGISTER = 60000*2  # check registration every 2 minutes
+BDH_TIMEOUT_MUL = 3
 
 
 # -----------------------------------------------------------------------------
@@ -111,14 +112,18 @@ def get_address_port_hostname(sockets, dns_suffix):
 ###############################################################################
 class DataServer(tornado.tcpserver.TCPServer):
     """
-    NB: a roundtrip should take at most blp_timeout + 2*tcp_timeout + cpu time
+    NB:
+        - a BDP roundtrip should take at most:
+                blp_timeout + 2*tcp_timeout + cpu time
+        - a BDH roundtrip should take at most:
+                BDH_TIMEOUT_MUL*blp_timeout + 2*tcp_timeout + cpu time
     """
     # -------------------------------------------------------------------------
     def __init__(
         self,
         logger=None,
         nthreads=10,
-        blp_timeout=500,  # milliseconds
+        blp_timeout=1000, # milliseconds
         tcp_timeout=100   # milliseconds
     ):
         super().__init__()
@@ -238,10 +243,11 @@ class DataServer(tornado.tcpserver.TCPServer):
             else:
                 # --- for BDH requests allow for much longer timeout
                 resp = await self.thrd_async(
-                    bdh_request, 5*self.blp_timeout, request)
+                    bdh_request, BDH_TIMEOUT_MUL*self.blp_timeout, request)
         except TimeoutError:
             err_msg = \
                 f"bloomberg request timed out after {self.blp_timeout!s} ms"
+            self.logger.info(err_msg)
             resp = {
                 "type": "TimeoutError",
                 "payload": err_msg
